@@ -1,6 +1,7 @@
-package v2
+package printer
 
 import (
+	"context"
 	_ "embed"
 	"html/template"
 	"os"
@@ -8,10 +9,10 @@ import (
 	"sort"
 	"strings"
 
-	logger "github.com/kubescape/go-logger"
+	"github.com/kubescape/go-logger"
 	"github.com/kubescape/go-logger/helpers"
-	"github.com/kubescape/kubescape/v2/core/cautils"
-	"github.com/kubescape/kubescape/v2/core/pkg/resultshandling/printer"
+	"github.com/kubescape/kubescape/v3/core/cautils"
+	"github.com/kubescape/kubescape/v3/core/pkg/resultshandling/printer"
 	"github.com/kubescape/opa-utils/reporthandling/apis"
 	"github.com/kubescape/opa-utils/reporthandling/results/v1/reportsummary"
 	"github.com/kubescape/opa-utils/reporthandling/results/v1/resourcesresults"
@@ -25,6 +26,8 @@ const (
 //go:embed html/report.gohtml
 var reportTemplate string
 
+var _ printer.IPrinter = &HtmlPrinter{}
+
 type HTMLReportingCtx struct {
 	OPASessionObj     *cautils.OPASessionObj
 	ResourceTableView ResourceTableView
@@ -38,17 +41,28 @@ func NewHtmlPrinter() *HtmlPrinter {
 	return &HtmlPrinter{}
 }
 
-func (htmlPrinter *HtmlPrinter) SetWriter(outputFile string) {
-	if outputFile == "" {
-		outputFile = htmlOutputFile
+func (hp *HtmlPrinter) SetWriter(ctx context.Context, outputFile string) {
+	if outputFile != "" {
+		if strings.TrimSpace(outputFile) == "" {
+			outputFile = htmlOutputFile
+		}
+		if filepath.Ext(strings.TrimSpace(outputFile)) != htmlOutputExt {
+			outputFile = outputFile + htmlOutputExt
+		}
 	}
-	if filepath.Ext(strings.TrimSpace(outputFile)) != htmlOutputExt {
-		outputFile = outputFile + htmlOutputExt
-	}
-	htmlPrinter.writer = printer.GetWriter(outputFile)
+	hp.writer = printer.GetWriter(ctx, outputFile)
 }
 
-func (htmlPrinter *HtmlPrinter) ActionPrint(opaSessionObj *cautils.OPASessionObj) {
+func (hp *HtmlPrinter) PrintNextSteps() {
+
+}
+
+func (hp *HtmlPrinter) ActionPrint(ctx context.Context, opaSessionObj *cautils.OPASessionObj, imageScanData []cautils.ImageScanData) {
+	if opaSessionObj == nil {
+		logger.L().Ctx(ctx).Error("failed to print results, missing data")
+		return
+	}
+
 	tplFuncMap := template.FuncMap{
 		"sum": func(nums ...int) int {
 			total := 0
@@ -104,14 +118,16 @@ func (htmlPrinter *HtmlPrinter) ActionPrint(opaSessionObj *cautils.OPASessionObj
 
 	resourceTableView := buildResourceTableView(opaSessionObj)
 	reportingCtx := HTMLReportingCtx{opaSessionObj, resourceTableView}
-	err := tpl.Execute(htmlPrinter.writer, reportingCtx)
+	err := tpl.Execute(hp.writer, reportingCtx)
 	if err != nil {
-		logger.L().Error("failed to render template", helpers.Error(err))
+		logger.L().Ctx(ctx).Error("failed to render template", helpers.Error(err))
+		return
 	}
+	printer.LogOutputFile(hp.writer.Name())
+
 }
 
-func (htmlPrinter *HtmlPrinter) Score(score float32) {
-	return
+func (hp *HtmlPrinter) Score(score float32) {
 }
 
 func buildResourceTableView(opaSessionObj *cautils.OPASessionObj) ResourceTableView {
@@ -132,7 +148,7 @@ func buildResourceControlResult(resourceControl resourcesresults.ResourceAssocia
 	ctlName := resourceControl.GetName()
 	ctlID := resourceControl.GetID()
 	ctlURL := cautils.GetControlLink(resourceControl.GetID())
-	failedPaths := append(failedPathsToString(&resourceControl), fixPathsToString(&resourceControl)...)
+	failedPaths := AssistedRemediationPathsToString(&resourceControl)
 
 	return ResourceControlResult{ctlSeverity, ctlName, ctlID, ctlURL, failedPaths}
 }
@@ -141,7 +157,7 @@ func buildResourceControlResultTable(resourceControls []resourcesresults.Resourc
 	var ctlResults []ResourceControlResult
 	for _, resourceControl := range resourceControls {
 		if resourceControl.GetStatus(nil).IsFailed() {
-			control := summaryDetails.Controls.GetControl(reportsummary.EControlCriteriaName, resourceControl.GetName())
+			control := summaryDetails.Controls.GetControl(reportsummary.EControlCriteriaID, resourceControl.GetID())
 			ctlResult := buildResourceControlResult(resourceControl, control)
 
 			ctlResults = append(ctlResults, ctlResult)
