@@ -1,17 +1,21 @@
 package v1
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 	"os"
 	"path/filepath"
 
-	logger "github.com/kubescape/go-logger"
-	"github.com/kubescape/go-logger/helpers"
-	"github.com/kubescape/kubescape/v2/core/cautils"
-	utilsapisv1 "github.com/kubescape/opa-utils/httpserver/apis/v1"
-
 	"github.com/google/uuid"
+	"github.com/kubescape/go-logger"
+	"github.com/kubescape/go-logger/helpers"
+	"github.com/kubescape/kubescape/v3/core/cautils"
+	"github.com/kubescape/kubescape/v3/core/cautils/getter"
+	apisv1 "github.com/kubescape/opa-utils/httpserver/apis/v1"
+	utilsapisv1 "github.com/kubescape/opa-utils/httpserver/apis/v1"
+	utilsmetav1 "github.com/kubescape/opa-utils/httpserver/meta/v1"
+	"go.opentelemetry.io/otel/trace"
 )
 
 // Metrics http listener for prometheus support
@@ -31,17 +35,16 @@ func (handler *HTTPHandler) Metrics(w http.ResponseWriter, r *http.Request) {
 		},
 		scanInfo: scanInfo,
 		scanID:   scanID,
+		ctx:      trace.ContextWithSpanContext(context.Background(), trace.SpanContextFromContext(r.Context())),
+		resp:     make(chan *utilsmetav1.Response, 1),
 	}
 
-	handler.scanResponseChan.set(scanID) // add scan to channel
-	defer handler.scanResponseChan.delete(scanID)
-
 	// send to scan queue
 	logger.L().Info("requesting scan", helpers.String("scanID", scanID), helpers.String("api", "v1/metrics"))
 	handler.scanRequestChan <- scanParams
 
 	// wait for scan to complete
-	results := <-handler.scanResponseChan.get(scanID)
+	results := <-scanParams.resp
 	defer removeResultsFile(scanID) // remove json format results file
 	defer os.Remove(resultsFile)    // remove prometheus format results file
 
@@ -68,14 +71,17 @@ func (handler *HTTPHandler) Metrics(w http.ResponseWriter, r *http.Request) {
 
 func getPrometheusDefaultScanCommand(scanID, resultsFile string) *cautils.ScanInfo {
 	scanInfo := defaultScanInfo()
-	scanInfo.Submit = false // do not submit results every scan
-	scanInfo.Local = true   // do not submit results every scan
+	scanInfo.UseArtifactsFrom = getter.DefaultLocalStore // Load files from cache (this will prevent kubescape fom downloading the artifacts every time)
+	scanInfo.Submit = false                              // do not submit results every scan
+	scanInfo.Local = true                                // do not submit results every scan
 	scanInfo.FrameworkScan = true
-	scanInfo.ScanAll = true                                                        // scan all frameworks
-	scanInfo.ScanID = scanID                                                       // scan ID
-	scanInfo.FailThreshold = 100                                                   // Do not fail scanning
-	scanInfo.Output = resultsFile                                                  // results output
-	scanInfo.Format = envToString("KS_FORMAT", "prometheus")                       // default output should be json
-	scanInfo.HostSensorEnabled.SetBool(envToBool("KS_ENABLE_HOST_SCANNER", false)) // enable host scanner
+	scanInfo.HostSensorEnabled.SetBool(false)                // disable host scanner
+	scanInfo.ScanAll = false                                 // do not scan all frameworks
+	scanInfo.ScanID = scanID                                 // scan ID
+	scanInfo.FailThreshold = 100                             // Do not fail scanning
+	scanInfo.ComplianceThreshold = 0                         // Do not fail scanning
+	scanInfo.Output = resultsFile                            // results output
+	scanInfo.Format = envToString("KS_FORMAT", "prometheus") // default output should be json
+	scanInfo.SetPolicyIdentifiers(getter.NativeFrameworks, apisv1.KindFramework)
 	return scanInfo
 }
