@@ -3,6 +3,7 @@ package v1
 import (
 	"testing"
 
+	"github.com/kubescape/kubescape/v3/httphandler/config"
 	apisv1 "github.com/kubescape/opa-utils/httpserver/apis/v1"
 	utilsmetav1 "github.com/kubescape/opa-utils/httpserver/meta/v1"
 	"github.com/stretchr/testify/assert"
@@ -11,9 +12,10 @@ import (
 func TestDefaultScanInfo(t *testing.T) {
 	s := defaultScanInfo()
 
-	assert.Equal(t, "", s.Credentials.Account)
+	assert.Equal(t, "", s.AccountID)
 	assert.Equal(t, "v2", s.FormatVersion)
 	assert.Equal(t, "json", s.Format)
+	assert.Equal(t, "", s.AccessKey)
 	assert.False(t, s.HostSensorEnabled.GetBool())
 	assert.False(t, s.Local)
 	assert.False(t, s.Submit)
@@ -24,10 +26,28 @@ func TestGetScanCommand(t *testing.T) {
 		TargetType: apisv1.KindFramework,
 	}
 	s := getScanCommand(&req, "abc")
-	assert.Equal(t, "", s.Credentials.Account)
+	assert.Equal(t, "", s.AccountID)
 	assert.Equal(t, "abc", s.ScanID)
 	assert.Equal(t, "v2", s.FormatVersion)
 	assert.Equal(t, "json", s.Format)
+	assert.Equal(t, "", s.AccessKey)
+	assert.False(t, s.HostSensorEnabled.GetBool())
+	assert.False(t, s.Local)
+	assert.False(t, s.Submit)
+}
+
+func TestGetScanCommandWithAccessKey(t *testing.T) {
+	config.SetAccessKey("test-123")
+
+	req := utilsmetav1.PostScanRequest{
+		TargetType: apisv1.KindFramework,
+	}
+	s := getScanCommand(&req, "abc")
+	assert.Equal(t, "", s.AccountID)
+	assert.Equal(t, "abc", s.ScanID)
+	assert.Equal(t, "v2", s.FormatVersion)
+	assert.Equal(t, "json", s.Format)
+	assert.Equal(t, "test-123", s.AccessKey)
 	assert.False(t, s.HostSensorEnabled.GetBool())
 	assert.False(t, s.Local)
 	assert.False(t, s.Submit)
