@@ -1,6 +1,7 @@
 package v1
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"os"
@@ -8,59 +9,95 @@ import (
 	"strings"
 
 	"github.com/armosec/utils-go/boolutils"
-	logger "github.com/kubescape/go-logger"
+	"github.com/kubescape/backend/pkg/versioncheck"
+	"github.com/kubescape/go-logger"
 	"github.com/kubescape/go-logger/helpers"
-	"github.com/kubescape/kubescape/v2/core/cautils"
-	"github.com/kubescape/kubescape/v2/core/cautils/getter"
-	"github.com/kubescape/kubescape/v2/core/core"
+	"github.com/kubescape/kubescape/v3/core/cautils"
+	"github.com/kubescape/kubescape/v3/core/cautils/getter"
+	"github.com/kubescape/kubescape/v3/core/core"
+	"github.com/kubescape/kubescape/v3/httphandler/config"
+	"github.com/kubescape/kubescape/v3/httphandler/storage"
 	utilsapisv1 "github.com/kubescape/opa-utils/httpserver/apis/v1"
 	utilsmetav1 "github.com/kubescape/opa-utils/httpserver/meta/v1"
 	reporthandlingv2 "github.com/kubescape/opa-utils/reporthandling/v2"
+	"go.opentelemetry.io/otel"
+	"go.opentelemetry.io/otel/attribute"
+	"go.opentelemetry.io/otel/trace"
 )
 
-// executeScan execute the scan request passed in the channel
-func (handler *HTTPHandler) executeScan() {
-	for {
-		scanReq := <-handler.scanRequestChan
+var scanImpl = scan // Override for testing
+func (handler *HTTPHandler) executeScan(scanReq *scanRequestParams) {
+	response := &utilsmetav1.Response{}
 
-		logger.L().Info("triggering scan", helpers.String("scanID", scanReq.scanID))
-
-		response := &utilsmetav1.Response{}
-
-		logger.L().Info("scan triggered", helpers.String("ID", scanReq.scanID))
-		results, err := scan(scanReq.scanInfo, scanReq.scanID)
-		if err != nil {
-			logger.L().Error("scanning failed", helpers.String("ID", scanReq.scanID), helpers.Error(err))
-			if scanReq.scanQueryParams.ReturnResults {
-				response.Type = utilsapisv1.ErrorScanResponseType
-				response.Response = err.Error()
-			}
-		} else {
-			logger.L().Success("done scanning", helpers.String("ID", scanReq.scanID))
-			if scanReq.scanQueryParams.ReturnResults {
-				response.Type = utilsapisv1.ResultsV1ScanResponseType
-				response.Response = results
-			}
+	logger.L().Info("scan triggered", helpers.String("ID", scanReq.scanID))
+	_, err := scanImpl(scanReq.ctx, scanReq.scanInfo, scanReq.scanID)
+	if err != nil {
+		logger.L().Ctx(scanReq.ctx).Error("scanning failed", helpers.String("ID", scanReq.scanID), helpers.Error(err))
+		if scanReq.scanQueryParams.ReturnResults {
+			response.Type = utilsapisv1.ErrorScanResponseType
+			response.Response = err.Error()
 		}
+	} else {
+		logger.L().Ctx(scanReq.ctx).Success("done scanning", helpers.String("ID", scanReq.scanID))
+		if scanReq.scanQueryParams.ReturnResults {
+			//TODO(ttimonen) should we actually pass the PostureReport here somehow?
+			response.Type = utilsapisv1.ResultsV1ScanResponseType
+		}
+	}
 
-		handler.state.setNotBusy(scanReq.scanID)
-
-		// return results
-		handler.scanResponseChan.push(scanReq.scanID, response)
+	handler.state.setNotBusy(scanReq.scanID)
 
+	// return results, if someone's waiting for them; never block.
+	select {
+	case scanReq.resp <- response:
+	default:
 	}
 }
-func scan(scanInfo *cautils.ScanInfo, scanID string) (*reporthandlingv2.PostureReport, error) {
 
-	ks := core.NewKubescape()
+// executeScan execute the scan request passed in the channel
+func (handler *HTTPHandler) watchForScan() {
+	for {
+		scanReq := <-handler.scanRequestChan
+		logger.L().Info("triggering scan", helpers.String("scanID", scanReq.scanID))
+		handler.executeScan(scanReq)
+	}
+}
+func scan(ctx context.Context, scanInfo *cautils.ScanInfo, scanID string) (*reporthandlingv2.PostureReport, error) {
+	ctx, spanScan := otel.Tracer("").Start(ctx, "kubescape.scan")
+	defer spanScan.End()
+
+	ks := core.NewKubescape(ctx)
+
+	spanScan.AddEvent("scanning metadata",
+		trace.WithAttributes(attribute.String("version", versioncheck.BuildNumber)),
+		trace.WithAttributes(attribute.String("build", versioncheck.Client)),
+		trace.WithAttributes(attribute.String("scanID", scanInfo.ScanID)),
+		trace.WithAttributes(attribute.Bool("scanAll", scanInfo.ScanAll)),
+		trace.WithAttributes(attribute.Bool("HostSensorEnabled", scanInfo.HostSensorEnabled.GetBool())),
+		trace.WithAttributes(attribute.String("excludedNamespaces", scanInfo.ExcludedNamespaces)),
+		trace.WithAttributes(attribute.String("includeNamespaces", scanInfo.IncludeNamespaces)),
+		trace.WithAttributes(attribute.String("hostSensorYamlPath", scanInfo.HostSensorYamlPath)),
+	)
+
 	result, err := ks.Scan(scanInfo)
 	if err != nil {
 		return nil, writeScanErrorToFile(err, scanID)
 	}
-	if err := result.HandleResults(); err != nil {
+	if err := result.HandleResults(ctx, scanInfo); err != nil {
 		return nil, err
 	}
-	return result.GetResults(), nil
+	storage := storage.GetStorage()
+	if storage != nil {
+		pr := result.GetResults()
+
+		if err := storage.StorePostureReportResults(ctx, pr); err != nil {
+			return nil, err
+		}
+	} else {
+		logger.L().Debug("storage is not initialized - skipping storing results")
+	}
+
+	return nil, nil
 }
 
 func readResultsFile(fileID string) (*reporthandlingv2.PostureReport, error) {
@@ -137,7 +174,9 @@ func getScanCommand(scanRequest *utilsmetav1.PostScanRequest, scanID string) *ca
 func defaultScanInfo() *cautils.ScanInfo {
 	scanInfo := &cautils.ScanInfo{}
 	scanInfo.FailThreshold = 100
-	scanInfo.Credentials.Account = envToString("KS_ACCOUNT", "")                   // publish results to Kubescape SaaS
+	scanInfo.ComplianceThreshold = 0
+	scanInfo.AccountID = envToString("KS_ACCOUNT_ID", config.GetAccount())         // publish results to Kubescape SaaS
+	scanInfo.AccessKey = envToString("KS_ACCESS_KEY", config.GetAccessKey())       // publish results to Kubescape SaaS
 	scanInfo.ExcludedNamespaces = envToString("KS_EXCLUDE_NAMESPACES", "")         // namespaces to exclude
 	scanInfo.IncludeNamespaces = envToString("KS_INCLUDE_NAMESPACES", "")          // namespaces to include
 	scanInfo.HostSensorYamlPath = envToString("KS_HOST_SCAN_YAML", "")             // path to host scan YAML
@@ -145,10 +184,12 @@ func defaultScanInfo() *cautils.ScanInfo {
 	scanInfo.Format = envToString("KS_FORMAT", "json")                             // default output should be json
 	scanInfo.Submit = envToBool("KS_SUBMIT", false)                                // publish results to Kubescape SaaS
 	scanInfo.Local = envToBool("KS_KEEP_LOCAL", false)                             // do not publish results to Kubescape SaaS
+	scanInfo.EnableRegoPrint = envToBool("KS_REGO_PRINT", false)                   // print rego rules
 	scanInfo.HostSensorEnabled.SetBool(envToBool("KS_ENABLE_HOST_SCANNER", false)) // enable host scanner
 	if !envToBool("KS_DOWNLOAD_ARTIFACTS", false) {
 		scanInfo.UseArtifactsFrom = getter.DefaultLocalStore // Load files from cache (this will prevent kubescape fom downloading the artifacts every time)
 	}
+
 	return scanInfo
 }
 
